==> jasperreports-3.7.6-sources.jar: net/sf/jasperreports/engine/type/RunDirectionEnum.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine.type;

import net.sf.jasperreports.engine.JRConstants;


/**
 * @author sanda zaharia (shertage@users.sourceforge.net)
 * @version $Id: RunDirectionEnum.java 3439 2010-02-18 14:57:42Z teodord $
 */
public enum RunDirectionEnum implements JREnum
{
	/**
	 * Constant useful to specify that text flows from left to right.
	 */
	LTR((byte)0, "LTR"),

	/**
	 * Constant useful to specify that text flows from right to left.
	 */
	RTL((byte)1, "RTL");
	
	/**
	 *
	 */
	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
	private final transient byte value;
	private final transient String name;

	private RunDirectionEnum(byte value, String name)
	{
		this.value = value;
		this.name = name;
	}

	/**
	 *
	 */
	public Byte getValueByte()
	{
		return new Byte(value);
	}
	
	/**
	 *
	 */
	public final byte getValue()
	{
		return value;
	}
	
	/**
	 *
	 */
	public String getName()
	{
		return name;
	}
	
	/**
	 *
	 */
	public static RunDirectionEnum getByName(String name)
	{
		return (RunDirectionEnum)EnumUtil.getByName(values(), name);
	}
	
	/**
	 *
	 */
	public static RunDirectionEnum getByValue(Byte value)
	{
		return (RunDirectionEnum)EnumUtil.getByValue(values(), value);
	}
	
	/**
	 *
	 */
	public static RunDirectionEnum getByValue(byte value)
	{
		return getByValue(new Byte(value));
	}

}

==> jasperreports-7.0.1-sources.jar: net/sf/jasperreports/engine/type/RunDirectionEnum.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2023 Cloud Software Group, Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine.type;


/**
 * @author Sanda Zaharia (shertage@users.sourceforge.net)
 */
public enum RunDirectionEnum implements NamedEnum
{
	/**
	 * Constant useful to specify that text flows from left to right.
	 */
	LTR("LTR"),

	/**
	 * Constant useful to specify that text flows from right to left.
	 */
	RTL("RTL");
	
	/**
	 *
	 */
	private final transient String name;

	private RunDirectionEnum(String name)
	{
		this.name = name;
	}
	
	@Override
	public String getName()
	{
		return name;
	}
	
	/**
	 *
	 */
	public static RunDirectionEnum getByName(String name)
	{
		return EnumUtil.getEnumByName(values(), name);
	}
	
	@Override
	public RunDirectionEnum getDefault()
	{
		return LTR;
	}
}
